# $Id$
#
# Copyright (c) 2005 Daisuke Maki <dmaki@cpan.org>
# All rights reserved.

package File::Extract::Filter;
use strict;



__END__

=head1 AUTHOR

Thanks to Tatsuhiko Miyagawa for the idea of filters :)

=cut